<?php

namespace Drupal\tidy_html\EventSubscriber;

use Drupal\tidy_html\TidyInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\FilterResponseEvent;
use Symfony\Component\HttpKernel\KernelEvents;

/**
 * A response filter that beautifies HTML responses.
 *
 * @package Drupal\tidy\EventSubscriber
 */
class TidyResponseFilter implements EventSubscriberInterface {

  const SUBSCRIBED_EVENTS = [KernelEvents::RESPONSE => 'onResponse'];

  /**
   * The tidy service.
   *
   * @var \Drupal\tidy_html\TidyInterface
   */
  protected $tidy;

  /**
   * Creates a new tidy response filter object.
   *
   * @param \Drupal\tidy_html\TidyInterface $tidy
   *   The tidy service.
   */
  public function __construct(TidyInterface $tidy) {
    $this->tidy = $tidy;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return static::SUBSCRIBED_EVENTS;
  }

  /**
   * Subscriber callback for the kernel response event.
   *
   * @param \Symfony\Component\HttpKernel\Event\FilterResponseEvent $event
   *   The event that was dispatched.
   */
  public function onResponse(FilterResponseEvent $event) {

    $response = $event->getResponse();
    $content_type = $response->headers->get('Content-Type');
    if (stripos($content_type, 'text/html') === FALSE) {
      return;
    }

    $response->setContent($this->tidy->beautify($response->getContent()));
  }

}
